#
# spec file for package python-wsgi_intercept
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-wsgi_intercept
Version:        1.8.0
Release:        3.1
Summary:        Installs a WSGI application in place of a real URI for testing
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/cdent/python3-wsgi-intercept
Source:         https://pypi.io/packages/source/w/wsgi_intercept/wsgi_intercept-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# Test requirements:
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module httplib2}
BuildRequires:  %{python_module pytest >= 2.4}
BuildRequires:  %{python_module requests >= 2.0.1}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module urllib3 >= 1.11.0}
BuildRequires:  fdupes
Requires:       python-six
%if 0%{?_no_weakdeps}
Requires:       python-requests >= 2.0.1
%else
Recommends:     python-requests >= 2.0.1
%endif
BuildArch:      noarch

%python_subpackages

%description
Testing a WSGI application normally involves starting a server at a local host
and port, then pointing your test code to that address. Instead, this library
lets you intercept calls to any specific host/port combination and redirect
them into a `WSGI application`_ importable by your test program.  Thus, you
can avoid spawning multiple processes or threads to test your Web app.

%prep
%setup -q -n wsgi_intercept-%{version}
%if 0%{?suse_version} == 1230
%patch0 -p1
%endif

%build
%python_build

%install
%python_install
rm -r %{buildroot}%{python_sitelib}/wsgi_intercept/tests
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export WSGI_INTERCEPT_SKIP_NETWORK=true
%python_exec -m pytest --ignore _build.python2 --ignore _build.python3

%files %{python_files}
%{python_sitelib}/wsgi_intercept-%{version}-py%{py_ver}.egg-info
%{python_sitelib}/wsgi_intercept

%changelog
* Thu Mar 21 2019 tbechtold@suse.com
- Add back devel dependency to be able to build on SLE12SP4. Without
  it, the build fails with:
  ImportError: cannot import name HTTPSConnection
* Sat Mar  9 2019 jayvdb@gmail.com
- Fix removal of tests from runtime package
- Run tests on both Python 2 and 3
- Use documented method of disabling network unit tests
- Remove no longer needed wsgi_intercept-disable-testbogusdomain.patch
- Add fdupes
- Update to v1.8.0
  * Add wheel support
- from v1.7.0
  * Allow nested interceptor context managers
- from v1.6.0
  * set wsgi.errors to sys.stderr
- from v1.5.1
  * Use fewer dependencies when building docs
  * Ignore `socket_options` for urllib3
* Thu Jan 10 2019 jbrownell@suse.com
- Support older OS targets by adding a fallback for Recommends:
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Jul  5 2017 tbechtold@suse.com
- convert to singlespec
* Tue May 16 2017 dmueller@suse.com
- update to 1.5.0:
  * compatibility fixes
* Wed Sep 28 2016 tbechtold@suse.com
- Add missing BuildRequires for pyrthon-six
* Tue Sep 27 2016 dmueller@suse.com
- update to 1.4.1
  * Correct the bytes v str problem
  * Fix pep8 errors in doc string
  * Move tests from the test dir into wsgi_intercept/tests
* Fri Sep  2 2016 tbechtold@suse.com
  update to version v1.3.1
  * Dedupe the urllib3 monkey patching code
  * Fix for python3 in use of urllib3.Response.data
  * add urllib3 to testing requires
  * update readme
  * Skip the network tests if WSGI_INTERCEPT_SKIP_NETWORK
  * Release 1.2.1
  * Force urllib3 to raise errors immediately
  * Release 1.3.0
  * Release 1.3.1
  * Small fix in docstring
  * Add urllib3 to the docs
  * make urllib3 min requirement explicit
  * Add support for intercepting urllib3
  * Don't use six when testing httplib
  * Release 1.2.0
  * Ensure header values are native str
  * fix typo in test/README
  * Release 1.1.3
- Use pypi.io (https) as Source url
* Mon Feb  1 2016 dmueller@suse.com
- update to 1.1.2:
  * no changelog available
* Mon Feb  1 2016 dmueller@suse.com
- update to 0.10.3:
  * bugfixes, no changelog available
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 0.10.0:
  * no changelog available
- refresh wsgi_intercept-disable-testbogusdomain.patch
- update project URL
- skip tests trying to access google.com with command line option
* Wed Feb  5 2014 speilicke@suse.com
- Use py.test rather than nosetests, testsuite uses py.test specific features
* Thu Jan 30 2014 speilicke@suse.com
- Added wsgi_intercept-disable-testbogusdomain.patch: Disable some tests
  on 12.3 where patching fails
* Thu Jan 30 2014 speilicke@suse.com
- Update to version 0.6.1:
  + Better testing dependency structure
- Dropped patches:
  + 0001-Depend-on-requests-2.0.1.patch (merged upstream)
* Thu Jan 30 2014 speilicke@suse.com
- Added 0001-Depend-on-requests-2.0.1.patch: Require requests>=2.0.1.
  Really a requirement
* Fri Jan 17 2014 speilicke@suse.com
- Don't install testsuite globally
- Run testsuite
- Fix requirement list
- Recommend python-requests for the requests-based backend
  (don't recommend httplib2, it isn't any better than the stdlib
  module 'httplib' due to it's SSL insufficencies)
* Fri Jan 17 2014 dmueller@suse.com
- remove excessive buildrequires that are not used due to
  tests being commented out
* Fri Nov 15 2013 p.drouand@gmail.com
- Update to version 0.6.0
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
